@@ -8,6 +8,7 @@
 #' @param beta beta value (default = 0.4)
 #' @param minClusterSize minimum length of cluster to retain (default = 10)
 #' @param CCmethod Methods for correlation coefficient calculation (default = "pearson"). Users can also pick "spearman".
+#' @param normalization Determine if normalization is needed on massive correlation coefficient matrix.
 #' @return mergedCluster - An merged clusters group
 #'
 #' @examples
@@ -24,10 +25,21 @@
 #' @import stats
 #' @export
 
-lmQCM <- function(data_in,gamma=0.55,t=1,lambda=1,beta=0.4,minClusterSize=10,CCmethod="pearson") {
+lmQCM <- function(data_in,gamma=0.55,t=1,lambda=1,beta=0.4,minClusterSize=10,CCmethod="pearson", normalization = F) {
   print("Calculating massive correlation coefficient ...")
-  cMatrix = cor(t(data_in), method = CCmethod)
+  cMatrix <- cor(t(data_in), method = CCmethod)
   diag(cMatrix) <- 0
+
+  if(normalization){
+    # Normalization
+    cMatrix <- abs(cMatrix)
+    D <- rowSums(cMatrix)
+    D.half <- 1/sqrt(D)
+
+    cMatrix <- apply(cMatrix, 2, function(x) x*D.half )
+    cMatrix <- t(apply(cMatrix, 1, function(x) x*D.half ))
+  }
+
   C <- localMaximumQCM(cMatrix, gamma, t, lambda)
   mergedCluster <- merging_lmQCM(C, beta, minClusterSize)
   print("Done.")
